A simple yet powerful library for controlling graphical displays. Multiple display controllers are supported using inheritance.

Dependents:   mbed_rifletool Hexi_Bubble_Game Hexi_Catch-the-dot_Game Hexi_Acceleromagnetic_Synth

NOTE: This library is in beta right now. As far as I know, everything here works, but there are many features that are lacking so far. Most notably containers, button handling, and display drivers other than the SSD1306.

Revision:
2:bbfc18022ee5
Parent:
1:f7003ec66a51
--- a/Abstracts/Display.h	Fri Mar 14 19:17:44 2014 +0000
+++ b/Abstracts/Display.h	Tue May 27 20:05:29 2014 +0000
@@ -49,9 +49,9 @@
      */
     virtual bool open() = 0;
 
     /** Finalize any writes to the Display
      */
-    virtual void finalize();
+    virtual void flush();
 
     /** Get the current state of the Display
      *
@@ -49,9 +49,9 @@
     virtual bool open() = 0;
 
-    /** Finalize any writes to the Display
+    /** flush any writes to the Display
      */